@@ -6,6 +6,7 @@
 #' @param class String. HTML table class.
 #' @param css Character vector. CSS style declarations.
 #' @param css_rule String. Complete CSS rules.
+#' @param script String. Custom JavaScript code or script tags to inject into the HTML output. Useful for loading external JavaScript libraries like Plotly, D3, etc.
 #' @param portable Logical. Sets whether to create portable HTML output with embedded Javascript, CSS, and base64-encoded images.
 #' @param tabulator_stylesheet Character string. CSS stylesheet theme for Tabulator.js tables.
 #'   Default is "bootstrap5". Available options: "default", "simple", "midnight", "modern",
@@ -23,11 +24,24 @@
 #'   - NULL (default): Preserves existing search settings, does not change previous configuration
 #'   - "top": Adds search box above the table
 #'   - "bottom": Adds search box below the table
+#'   - "column": Adds header filters to each column for per-column searching
 #' @param tabulator_options Custom Tabulator.js configuration options.
 #' @param tabulator_css_rule Complete CSS rules.
 #' @param tabulator_columns Custom column definitions.
 #' @param ... Additional arguments are ignored.
 #'
+#' @examples
+#' \dontrun{
+#' # Load an external JavaScript library
+#' library(tinytable)
+#' x <- tt(mtcars[1:5, 1:5])
+#' x <- theme_html(x, script = '<script src="https://cdn.plot.ly/plotly-2.27.0.min.js"></script>')
+#'
+#' # Add custom inline JavaScript
+#' x <- tt(mtcars[1:5, 1:5])
+#' x <- theme_html(x, script = '<script>console.log("Table loaded");</script>')
+#' }
+#'
 #' @export
 theme_html <- function(
     x,
@@ -37,6 +51,7 @@ theme_html <- function(
     class = get_option("tinytable_html_class", default = NULL),
     css = get_option("tinytable_html_css", default = NULL),
     css_rule = get_option("tinytable_html_css_rule", default = NULL),
+    script = get_option("tinytable_html_script", default = NULL),
     portable = get_option("tinytable_html_portable"),
     tabulator_columns = get_option("tinytable_html_tabulator_columns"),
     tabulator_css_rule = get_option("tinytable_html_tabulator_css_rule"),
@@ -48,10 +63,17 @@ theme_html <- function(
     ...) {
   assert_string(class, null.ok = TRUE)
   assert_choice(engine, c("tinytable", "bootstrap", "tabulator"), null.ok = TRUE)
-  assert_choice(tabulator_search, c("top", "bottom"), null.ok = TRUE)
+  assert_choice(tabulator_search, c("top", "bottom", "column"), null.ok = TRUE)
   sanity_tabulator_css_rule(tabulator_css_rule)
   sanity_tabulator_columns(tabulator_columns)
 
+  if (!isTRUE(portable) && isTRUE(Sys.info()["sysname"] == "Windows")) {
+    warning("On Windows, `tinytable` should embed images in the HTML file directly. Set  `theme_html(portable=TRUE)` explicitly to silence this warning.",
+      call. = FALSE
+    )
+  }
+
+
   if (!is.null(engine)) {
     x@html_engine <- engine
     if (engine == "bootstrap" && is.null(class) && identical(x@html_class, "tinytable")) {
@@ -64,6 +86,11 @@ theme_html <- function(
     x@html_css_rule <- css_rule
   }
 
+  if (!is.null(script)) {
+    assert_string(script)
+    x@html_script <- script
+  }
+
   if (!is.null(class)) {
     x@html_class <- class
   }
