@@ -4,5 +4,5 @@ theme_dictionary <- list(
   "revealjs" = theme_revealjs,
   "rotate" = theme_rotate,
   "striped" = theme_striped,
-  "void" = theme_void
+  "empty" = theme_empty
 )
